@@ -1,8 +1,6 @@
 """Cpuset manipulation command
 """
 
-from __future__ import unicode_literals
-from builtins import str
 __copyright__ = """
 Copyright (C) 2007-2010 Novell Inc.
 Copyright (C) 2013-2018 SUSE
@@ -484,7 +482,7 @@ def set_details(name, indent=None, width=None, usehex=False):
     if width != 0 and len(tst) > width:
         target = width - len(out)
         patha = set.path[:len(set.path)//2-3]
-        pathb = set.path[len(set.path//2):]
+        pathb = set.path[len(set.path)//2:]
         patha = patha[:target//2-3]
         pathb = pathb[-target//2:]
         out += patha + '...' + pathb
